opengleametry

Values

pub fn remove_default_logger() -> Nil

Utility function in case you do not need the default logger

pub fn remove_sasl_logger() -> Nil

Utility function in case you do not need the sasl logger. The sasl logger is what dumps otp/sasl logs, such as supervisor reports and crash reports.

pub fn set_opengleametry_logger() -> Nil

Add the OpenGleametry logger. Intended to replace the sasl logger.

Search Document