opengleametry/link
Types
An unchanging reference to a span context. You can persist this, and use it after rebooting your application. That is the reason this type is not opaque.
Note: I have not yet seen non-empty attributes or tracestate. I do not know what they entail.
pub type Link {
Link(
trace_id: Int,
span_id: Int,
attributes: List(#(String, String)),
tracestate: Tracestate,
)
}
Constructors
-
Link( trace_id: Int, span_id: Int, attributes: List(#(String, String)), tracestate: Tracestate, )
pub type Tracestate {
Tracestate(List(#(String, String)))
}
Constructors
-
Tracestate(List(#(String, String)))